/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import com.liferay.jenkins.results.parser.GitWorkingDirectory.Remote;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Peter Yoo
 */
public class RepositoryFactory {

	public static LocalRepository getLocalRepository(
		String repositoryName, String upstreamBranchName) {

		String key = repositoryName + "/" + upstreamBranchName;

		if (_localRepositories.containsKey(key)) {
			return _localRepositories.get(key);
		}

		LocalRepository localRepository = null;

		if (repositoryName.startsWith("com-liferay-")) {
			localRepository = new SubrepositoryLocalRepository(
				repositoryName, upstreamBranchName);
		}
		else if (repositoryName.startsWith("liferay-plugins")) {
			localRepository = new PluginsLocalRepository(
				repositoryName, upstreamBranchName);
		}
		else if (repositoryName.startsWith("liferay-portal")) {
			localRepository = new PortalLocalRepository(
				repositoryName, upstreamBranchName);
		}
		else {
			localRepository = new LocalRepository(
				repositoryName, upstreamBranchName);
		}

		_localRepositories.put(key, localRepository);

		return _localRepositories.get(key);
	}

	public static RemoteRepository getRemoteRepository(Remote remote) {
		String hostname = remote.getHostname();

		if (hostname.equalsIgnoreCase("github.com")) {
			return new GitHubRemoteRepository(remote);
		}

		return new RemoteRepository(remote);
	}

	public static RemoteRepository getRemoteRepository(
		String hostname, String repositoryName, String username) {

		if (hostname.equalsIgnoreCase("github.com")) {
			return new GitHubRemoteRepository(repositoryName, username);
		}

		return new RemoteRepository(hostname, repositoryName, username);
	}

	private static final Map<String, LocalRepository> _localRepositories =
		new HashMap<>();

}