/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

/**
 * @author Michael Hashimoto
 */
public class SubrepositoryLocalRepository extends LocalRepository {

	protected SubrepositoryLocalRepository(
		String name, String upstreamBranchName) {

		super(name, upstreamBranchName);

		if (upstreamBranchName.endsWith("-private") &&
			!name.endsWith("-private")) {

			throw new IllegalArgumentException(
				JenkinsResultsParserUtil.combine(
					"The local repository, ", name,
					" should not be used with upstream branch ",
					upstreamBranchName, ". Use ", name, "-private."));
		}
	}

	@Override
	protected String getDefaultRelativeRepositoryDirPath() {
		String name = getName();

		if (!name.endsWith("-private")) {
			return name + "-private";
		}

		return name;
	}

}